wspr: Regenerate VDL due to go/vcl/8494
Change-Id: I5db1044bffd96b99c1958b2401279977a2ca9b21
MultiPart: 5/8
diff --git a/services/wsprd/channel/channel.vdl b/services/wsprd/channel/channel.vdl
index caf98f1..8f27c0a 100644
--- a/services/wsprd/channel/channel.vdl
+++ b/services/wsprd/channel/channel.vdl
@@ -12,7 +12,7 @@
Body any
}
-type Message oneof {
+type Message union {
Request Request
Response Response
}
diff --git a/services/wsprd/channel/channel.vdl.go b/services/wsprd/channel/channel.vdl.go
index 4cbf3ca..ead937b 100644
--- a/services/wsprd/channel/channel.vdl.go
+++ b/services/wsprd/channel/channel.vdl.go
@@ -32,7 +32,7 @@
}
type (
// Message represents any single field of the Message oneof type.
Message interface {
// Index returns the field index.
Index() int
@@ -40,18 +40,18 @@
Interface() interface{}
// Name returns the field name.
Name() string
// __VDLReflect describes the Message oneof type.
__VDLReflect(__MessageReflect)
}
// MessageRequest represents field Request of the Message oneof type.
MessageRequest struct{ Value Request }
// MessageResponse represents field Response of the Message oneof type.
MessageResponse struct{ Value Response }
// __MessageReflect describes the Message oneof type.
__MessageReflect struct {
Name string "veyron.io/wspr/veyron/services/wsprd/channel.Message"
Type Message
- OneOf struct {
+ Union struct {
Request MessageRequest
Response MessageResponse
}
@@ -32,7 +32,7 @@
}
type (
- // Message represents any single field of the Message oneof type.
+ // Message represents any single field of the Message union type.
Message interface {
// Index returns the field index.
@@ -40,18 +40,18 @@
// Name returns the field name.
Name() string
- // __VDLReflect describes the Message oneof type.
+ // __VDLReflect describes the Message union type.
__VDLReflect(__MessageReflect)
}
@@ -40,18 +40,18 @@
__VDLReflect(__MessageReflect)
}
- // MessageRequest represents field Request of the Message oneof type.
+ // MessageRequest represents field Request of the Message union type.
MessageRequest struct{ Value Request }
@@ -40,18 +40,18 @@
MessageRequest struct{ Value Request }
- // MessageResponse represents field Response of the Message oneof type.
+ // MessageResponse represents field Response of the Message union type.
MessageResponse struct{ Value Response }
@@ -40,18 +40,18 @@
MessageResponse struct{ Value Response }
- // __MessageReflect describes the Message oneof type.
+ // __MessageReflect describes the Message union type.
__MessageReflect struct {
Name string "veyron.io/wspr/veyron/services/wsprd/channel.Message"